#ifndef EL__ECMASCRIPT_MUJS_SCREEN_H
#define EL__ECMASCRIPT_MUJS_SCREEN_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

int mjs_screen_init(js_State *J);

#ifdef __cplusplus
}
#endif

#endif
